@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 import time
 
 import numpy as np
@@ -6,7 +7,7 @@ import pybullet as p
 import pybullet_data
 from pybullet_utils import bullet_client
 
-from PyFlyt.core.drone import Drone
+from .drone import Drone
 
 
 class Aviary(bullet_client.BulletClient):
@@ -21,9 +22,9 @@ class Aviary(bullet_client.BulletClient):
         drone_model: str = "cf2x",
         use_camera: bool = False,
         use_gimbal: bool = False,
-        camera_angle: int = 20,
-        camera_FOV: int = 90,
-        camera_frame_size: tuple[int, int] = (128, 128),
+        camera_angle_degrees: int = 20,
+        camera_FOV_degrees: int = 90,
+        camera_resolution: tuple[int, int] = (128, 128),
         seed: None | int = None,
     ):
         super().__init__(p.GUI if render else p.DIRECT)
@@ -42,9 +43,9 @@ class Aviary(bullet_client.BulletClient):
         self.start_orn = start_orn
         self.use_camera = use_camera
         self.use_gimbal = use_gimbal
-        self.camera_angle = camera_angle
-        self.camera_FOV = camera_FOV
-        self.camera_frame_size = camera_frame_size
+        self.camera_angle = camera_angle_degrees
+        self.camera_FOV = camera_FOV_degrees
+        self.camera_frame_size = camera_resolution
 
         self.model_dir = model_dir
         self.drone_model = drone_model
@@ -62,6 +63,14 @@ class Aviary(bullet_client.BulletClient):
         self.setGravity(0, 0, -9.81)
         self.steps = 0
 
+        # reset the camera position t a sane place
+        self.resetDebugVisualizerCamera(
+            cameraDistance=5,
+            cameraYaw=30,
+            cameraPitch=-45,
+            cameraTargetPosition=[0, 0, 1],
+        )
+
         # define new RNG
         self.np_random = np.random.RandomState(seed=seed)
 
@@ -74,7 +83,7 @@ class Aviary(bullet_client.BulletClient):
         # )
 
         # spawn drones
-        self.drones = []
+        self.drones: list[Drone] = []
         for start_pos, start_orn in zip(self.start_pos, self.start_orn):
             self.drones.append(
                 Drone(
@@ -87,16 +96,18 @@ class Aviary(bullet_client.BulletClient):
                     drone_model=self.drone_model,
                     use_camera=self.use_camera,
                     use_gimbal=self.use_gimbal,
-                    camera_angle=self.camera_angle,
-                    camera_FOV=self.camera_FOV,
-                    camera_frame_size=self.camera_frame_size,
+                    camera_angle_degrees=self.camera_angle,
+                    camera_FOV_degrees=self.camera_FOV,
+                    camera_resolution=self.camera_frame_size,
                     np_random=self.np_random,
                 )
             )
 
         # arm everything
         self.armed = [1] * self.num_drones
+        self.register_all_new_bodies()
 
+    def register_all_new_bodies(self):
         # collision array
         self.collision_array = np.zeros(
             (self.getNumBodies(), self.getNumBodies()), dtype=bool
